@@ -3,8 +3,6 @@ use nu_source::Spanned;
 use std::{fmt::Debug, sync::Arc};
 
 pub trait ParserScope: Debug {
-    fn get_names(&self) -> Vec<String>;
-
     fn get_signature(&self, name: &str) -> Option<nu_protocol::Signature>;
 
     fn has_signature(&self, name: &str) -> bool;
@@ -15,6 +13,8 @@ pub trait ParserScope: Debug {
 
     fn get_alias(&self, name: &str) -> Option<Vec<Spanned<String>>>;
 
+    fn remove_alias(&self, name: &str);
+
     fn add_alias(&self, name: &str, replacement: Vec<Spanned<String>>);
 
     fn enter_scope(&self);
